hydrointerp - A Python package for interpolating hydrologic data
===================================================================

The hydrointerp package includes several interpolation functions specifically designed for hydrologic data. These are mainly derived from `Scipy <https://docs.scipy.org/doc/scipy/reference/index.html>`_ interpolation functions like `griddata <https://docs.scipy.org/doc/scipy/reference/generated/scipy.interpolate.griddata.html>`_.

Documentation
--------------
The primary documentation for the package can be found `here <https://hydrointerp.readthedocs.io>`_.

Installation
------------
hydrointerp can be installed via pip or conda::

  pip install hydrointerp

or::

  conda install -c mullenkamp hydrointerp

The core dependencies are `Pandas <http://pandas.pydata.org/pandas-docs/stable/>`_,  `Scipy <https://docs.scipy.org/doc/scipy/reference/index.html>`_, `xarray <http://xarray.pydata.org/en/stable/>`_, and `pyproj <http://pyproj4.github.io/pyproj/html/index.html>`_.
